@@ -1,15 +1,15 @@
 import sys
 import itertools
 
-if sys.version_info[0] < 3:
-    PY3 = False
+PY3 = sys.version_info >= (3,)
+PY2 = not PY3
 
+if PY2:
     basestring = basestring
     import __builtin__ as builtins
     import ConfigParser
     from StringIO import StringIO
     BytesIO = StringIO
-    execfile = execfile
     func_code = lambda o: o.func_code
     func_globals = lambda o: o.func_globals
     im_func = lambda o: o.im_func
@@ -21,9 +21,6 @@ if sys.version_info[0] < 3:
     iteritems = lambda o: o.iteritems()
     long_type = long
     maxsize = sys.maxint
-    next = lambda o: o.next()
-    numeric_types = (int, long, float)
-    reduce = reduce
     unichr = unichr
     unicode = unicode
     bytes = str
@@ -31,29 +28,17 @@ if sys.version_info[0] < 3:
     import urllib2
     from urllib2 import urlopen, HTTPError, URLError, unquote, splituser
     from urlparse import urlparse, urlunparse, urljoin, urlsplit, urlunsplit
-    xrange = xrange
     filterfalse = itertools.ifilterfalse
+    filter = itertools.ifilter
+    map = itertools.imap
 
-    def exec_(code, globs=None, locs=None):
-        if globs is None:
-            frame = sys._getframe(1)
-            globs = frame.f_globals
-            if locs is None:
-                locs = frame.f_locals
-            del frame
-        elif locs is None:
-            locs = globs
-        exec("""exec code in globs, locs""")
-
-    exec_("""def reraise(tp, value, tb=None):
+    exec("""def reraise(tp, value, tb=None):
     raise tp, value, tb""")
-else:
-    PY3 = True
 
+if PY3:
     basestring = str
     import builtins
     import configparser as ConfigParser
-    exec_ = eval('exec')
     from io import StringIO, BytesIO
     func_code = lambda o: o.__code__
     func_globals = lambda o: o.__globals__
@@ -65,9 +50,6 @@ else:
     iteritems = lambda o: o.items()
     long_type = int
     maxsize = sys.maxsize
-    next = next
-    numeric_types = (int, float)
-    from functools import reduce
     unichr = chr
     unicode = str
     bytes = bytes
@@ -78,20 +60,9 @@ else:
         urlparse, urlunparse, unquote, splituser, urljoin, urlsplit,
         urlunsplit, splittag,
     )
-    xrange = range
     filterfalse = itertools.filterfalse
-
-    def execfile(fn, globs=None, locs=None):
-        if globs is None:
-            globs = globals()
-        if locs is None:
-            locs = globs
-        f = open(fn, 'rb')
-        try:
-            source = f.read()
-        finally:
-            f.close()
-        exec_(compile(source, fn, 'exec'), globs, locs)
+    filter = filter
+    map = map
 
     def reraise(tp, value, tb=None):
         if value.__traceback__ is not tb:
